@@ -13,14 +13,15 @@
  */
 package ch.qos.logback.core.rolling;
 
-import ch.qos.logback.core.encoder.EchoEncoder;
-import ch.qos.logback.core.util.CoreTestConstants;
+import java.io.IOException;
+import java.util.List;
+
 import org.junit.Before;
 import org.junit.Test;
 
-import java.io.IOException;
-import java.util.ArrayList;
-import java.util.List;
+import ch.qos.logback.core.encoder.EchoEncoder;
+import ch.qos.logback.core.util.CoreTestConstants;
+import ch.qos.logback.core.util.FileSize;
 
 public class SizeBasedRollingTest extends ScaffoldingForRollingTests {
 
@@ -51,7 +52,7 @@ public class SizeBasedRollingTest extends ScaffoldingForRollingTests {
      */
     @Test(expected = IllegalStateException.class)
     public void activeFileNameNotSet() {
-        sizeBasedTriggeringPolicy.setMaxFileSize("100");
+        sizeBasedTriggeringPolicy.setMaxFileSize(new FileSize(100));
         sizeBasedTriggeringPolicy.start();
 
         fwrp.setFileNamePattern(CoreTestConstants.OUTPUT_DIR_PREFIX + "sizeBased-test1.%i");
@@ -63,7 +64,7 @@ public class SizeBasedRollingTest extends ScaffoldingForRollingTests {
         rfa.setName("ROLLING");
         initRFA(randomOutputDir + fileName);
 
-        sizeBasedTriggeringPolicy.setMaxFileSize("100");
+        sizeBasedTriggeringPolicy.setMaxFileSize(new FileSize(100));
         fwrp.setMinIndex(0);
         fwrp.setFileNamePattern(randomOutputDir + filenamePattern);
 
